#
# spec file for package perl-Params-Util
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Params-Util
Version:        1.07
Release:        14.1
%define         cpan_name Params-Util
Summary:        Simple, compact and correct param-checking functions
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Params-Util/
Source:         http://www.cpan.org/authors/id/A/AD/ADAMK/%{cpan_name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::CBuilder) >= 0.27
#BuildRequires: perl(A)
#BuildRequires: perl(Params::Util)
%{perl_requires}

%description
'Params::Util' provides a basic set of importable functions that makes
checking parameters a hell of a lot easier

While they can be (and are) used in other contexts, the main point behind
this module is that the functions *both* Do What You Mean, and Do The Right
Thing, so they are most useful when you are getting params passed into your
code from someone and/or somewhere else and you can't really trust the
quality.

Thus, 'Params::Util' is of most use at the edges of your API, where params
and data are coming in from outside your code.

The functions provided by 'Params::Util' check in the most strictly correct
manner known, are documented as thoroughly as possible so their exact
behaviour is clear, and heavily tested so make sure they are not fooled by
weird data and Really Bad Things.

To use, simply load the module providing the functions you want to use as
arguments (as shown in the SYNOPSIS).

To aid in maintainability, 'Params::Util' will *never* export by default.

You must explicitly name the functions you want to export, or use the
':ALL' param to just have it export everything (although this is not
recommended if you have any _FOO functions yourself with which future
additions to 'Params::Util' may clash)

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes LICENSE MYMETA.json README

%changelog
* Fri Mar 16 2012 lars@linux-schulserver.de
- update to 1.07:
  + Disable XS version on cygwin as it shows bizarre behaviour
    that breaks form when using Params::Util XS verwion.
* Tue Mar  6 2012 coolo@suse.com
- updated to 1.06
  - Remove the need for the sanexs.c file by generating into a temp
    file instead.
  - Restore compatibility with pre-5.8.8 Perls without a working
    compiler available install time (RIBASUSHI)
* Sat Apr 30 2011 coolo@opensuse.org
- updated to 1.04
  - Fixed #67522 have_compiler returns
* Fri Apr  1 2011 coolo@novell.com
- update to 1.03
  - Trying for a much more advanced can_xs() alternative to can_cc()
    to deal with the situation where a host has a superficially
    working compiler, but completely screwed up headers.
  - Adding some fallback strategies to deal with cases where these
    same machines don't support configure_requires.
  - Adopt Chorny's eumm-upgrade style for the Makefile.PL.
  - Allow the Makefile.PL to build it's own META.yml now.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sun Apr  4 2010 chris@computersalat.de
- spec mods
  - fixed HEADER
  - updated Url
  - fixed perl-macros deps
* Sun Mar 21 2010 lars@linux-schulserver.de
- update to 1.01:
  + Fixed can_cc() bug in Makefile.PL where it was checking an
    existence of PATH directory rather than executables. RT#55668
    (DGOLDEN, MIYAGAWA)
- build parallel
* Thu Mar  4 2010 coolo@novell.com
- readd whitespace removed by autobuild
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Sun Jun 21 2009 chris@computersalat.de
- update to 1.00
  o 1.00 Sun 31 May 2009
  - Now all known XS bugs are worked out, I've removed
  the experimental flags and set that as the first 1+ release.
  - Fixed XS implementation of _*LIKE and _INSTANCE
  - Added test for a negative custom isa returning ('')
  - Improving the 'clean' file list in a Makefile.PL
  o 0.38 Tue 17 Feb 2009
  - Fix _IDENTIFIER to return false for "foo\n" (ZEFRAM)
  - Fix _CLASS to return false for "foo\n" (ZEFRAM)
  o 0.37 Wed  4 Feb 2009
  - Fix _HASH for bleadperl (patch from RAFL)
  - Fix regex (more) for bleadperl (patch from RAFL)
  o 0.36 Fri 30 Jan 2009
  - Fixing the overload for _REGEX
  - Adding the tests for _REGEX
  - Reorganising the Makefile.PL
  - Adding duplicate tests for when the XS version isn't compiled
- added perl-macros
  o autogen filelist with perl_gen_filelist
- spec mods
  o added header
* Sun Nov 30 2008 lars@linux-schulserver.de
- initial version 0.35
